# Specification: Partial Requirements

**ID**: SPEC-304
**Version**: 1.0
**Date**: 2025-10-24
**Status**: Draft

## Overview

This spec has only some requirements defined, but tests reference additional non-existent requirements.

## Requirements

**REQ-001**: The system shall do something.

**REQ-002**: The system shall do something else.

**REQ-005**: The system shall do a fifth thing (note: REQ-003 and REQ-004 are missing).
